@@ -1,8 +1,10 @@
 import importlib
 import json
 import os
+from os import path
 
-with open("../designer/data/" + "colors.json") as f:
+this_directory = path.abspath(path.dirname(__file__))
+with open(path.join(this_directory, 'data/colors.json'), encoding='utf-8') as f:
     colors = json.load(f)
     f.close()
 
